﻿using System;
using System.Threading;
using System.Configuration;
using Alachisoft.NCache.Runtime;
using Alachisoft.NCache.Web.Caching;
using Alachisoft.NCache.Runtime.Dependencies;

// ===============================================================================
// Alachisoft (R) NCache Sample Code.
// NCache File Based Dependency sample
// ===============================================================================
// Copyright © Alachisoft.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
// ===============================================================================


namespace Dependency
{
	public class FileBasedDependency
	{

		public static void RunFileBasedDependencyDemo()
		{
			try
			{
				//Initialize cache
				Cache cache;
				cache = NCache.InitializeCache("mypartitionedcache");
				cache.Clear();


                string filename = ConfigurationManager.AppSettings["FilePath"];
                
				//adding item dependent on file 
				cache.Add("Key-1", "Item dependent on file...", new FileDependency(filename), Cache.NoAbsoluteExpiration, Cache.NoSlidingExpiration, CacheItemPriority.Normal);

				//Change file samples\\dependency\\dist\\foobar.txt meanwhile program awaits...
                Console.WriteLine("Make changes in the text file while program waits for 5 seconds.");
				Thread.Sleep(5000);

				//... and then check for its existence
				object item = cache.Get("Key-1");
				if (item == null)
				{
					Console.WriteLine("Item has been removed due to file dependency.");
				}
				else
				{
					Console.WriteLine("File based dependency did not work. Dependency file located at " + filename + " might be missing or file not changed within the given interval.");
				}

				//Multiple files names can be specified in FileDependency parameter

				//Must dispose cache
				cache.Dispose();

			}
			catch (Exception ex)
			{
				Console.WriteLine(ex.Message);
			}
		}

	}

}